|Logo|

AmyPET
======

Amyloid imaging to prevent Alzheimer's Disease.


Install
-------

Requires Python 3.6 or greater. Choose one of the following:

.. code:: sh

    pip install amypet       # command line interface (CLI) version
    pip install amypet[gui]  # CLI and graphical user interface (GUI) version

For certain functionality (image trimming & resampling, DICOM to NIfTI converters) it may be required to also `pip install nimpa`.


Usage
-----

.. code:: sh

    amypet --help  # CLI version
    amypet.gui     # GUI version


.. |Logo| image:: https://amypad.eu/wp-content/themes/AMYPAD/images/AMYPAD_Logo.jpg
   :target: https://amypad.eu
